<?php

/*
	Plugin Name: WP Title 2
	Plugin URI: http://blog.ickata.net/wp-title-2/
	Description: Add custom Heading, different from the Title, used in page links. Compatible with WP_Multilingual and qTranslate Plugins.
	Author: Hristo Chakarov
	Version: 2.0.9
	Author URI: http://blog.ickata.net/
*/

/*

    Copyright 2008 HRISTO CHAKAROV  (email : mail@ickata.net)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
	
*/


// Rewriting db structure from 1.54 to 2.0
function ct_initial(){
	global $wpdb;
	$wpdb->query("UPDATE $wpdb->postmeta SET meta_key = CONCAT('_',meta_key) WHERE meta_key LIKE 'title_%'");
}
add_action('activate_wp-title-2/wp-title-2.php','ct_initial');


// Get the label translations
include('translations.php');

// Check if WP_Multilingual is installed
if (class_exists('WP_Multilingual')) $GLOBALS['WP_Multilingual_Langs'] = WP_Multilingual::AvaibleLanguages(); // get language list

// Check if qTranslate is installed
else if (function_exists('qtrans_loadConfig')) {
	$qtrans_available_langs = get_option('qtranslate_enabled_languages');
	$default_lang = $q_config['default_language'];
	foreach ($qtrans_available_langs as $v) {
		// get language list
		if ($v==$default_lang) $GLOBALS['WP_Multilingual_Langs']['default']['lang_shortcode'] = $v;
		else $GLOBALS['WP_Multilingual_Langs'][]['lang_shortcode'] = $v; 
	}
}
else if (WPLANG!='') $GLOBALS['WP_Multilingual_Langs']['default']['lang_shortcode'] = substr(WPLANG,0,strpos(WPLANG,'_')); // get the WP language
else $GLOBALS['WP_Multilingual_Langs']['default']['lang_shortcode'] = 'en'; // default: English

// Print the translated Heading label
function ct_getTranslatedLabel() {
	global $current_user,$wp_title2_label;
	get_currentuserinfo();
	$label = get_usermeta($current_user->ID,'wplocalization',true); // depending on User's language
	if ($label=='') $label = (WPLANG!='') ? WPLANG : 'none'; // If not WP_Multilingual, default WP language is used
	echo ($wp_title2_label[$label]!='') ? $wp_title2_label[$label] : $wp_title2_label['none'];
}

// Add the additional input field in New/Edit Post/Page form
function ct_addTitleField() {
	global $post;
	foreach($GLOBALS['WP_Multilingual_Langs'] as $v) {
		$customtitle = get_post_meta($post->ID, '_title_'.$v['lang_shortcode'], true);
?>
<fieldset class="customtitlediv" id="customtitle_<?php echo $v['lang_shortcode']; ?>">
	<legend><?php ct_getTranslatedLabel(); ?></legend>
	<div style="width:100%">
		<input class="customtitle" type="text" tabindex="1" size="30" name="title_<?php echo $v['lang_shortcode']; ?>" value="<?php echo $customtitle; ?>" />
	</div>
</fieldset>
<?php
	}
}

// Adding some CSS and JavaScript functions in the <head> in administration pages
function ct_addHead() {
	
	global $post;
	
	// Get WP version
	$version = substr($GLOBALS['wp_version'],0,strpos($GLOBALS['wp_version'],'.')+2);
	
	// Depending on the version, add different styles 
	switch($version) {
		
		case 2.3;
		include ('wp-version-2.3.php'); // for WP 2.3.*
		break;
		
		case 2.5;
		case 2.6;
		include ('wp-version-2.5.php'); // for WP 2.5.* and 2.6.*
		break;
		
		case 2.7;
		default;
		include ('wp-version-2.7.php'); // for WP 2.7 and above
		break;
		
	}
	
}

// Add/Update our Heading in the DataBase
function ct_updateTitle() {
	
	global $wpdb;
	
	if (isset($_POST)) {
		foreach($GLOBALS['WP_Multilingual_Langs'] as $v) {
			$language = $v['lang_shortcode'];
			if (isset($_POST['title_'.$language])) {
				
				// get the page id
				if (isset($_POST['post_ID'])) {
					$postID = $_POST['post_ID'];
				} else {
					$post = $wpdb->get_results("SELECT ID FROM {$wpdb->posts} WHERE post_type = 'page' ORDER BY ID DESC LIMIT 1");
					$postID = $post[0]->ID;
				}
				
				// adding the heading to the database
				if (!update_post_meta($postID, '_title_'.$language, stripslashes($_POST['title_'.$language]))) 
					add_post_meta($postID, '_title_'.$language, stripslashes($_POST['title_'.$language]),true);
			}
		}
	}
}

// Some filter, encodes special characters to entities
function ct_enc($s){
	$trans = array('&' => '&#038;','"' => '&#8220;');
	return strtr($s,$trans);
}

// Changing the the_title() Template Tag
function ct_the_title() {
	global $post,$language,$q_config;
	
	$args = func_get_args();
	$title = ct_enc($post->post_title);
	
	if (!isset($language)) $lang = (isset($q_config)) ? $q_config['language'] : $GLOBALS['WP_Multilingual_Langs']['default']['lang_shortcode'];
	else $lang = $language;
	
	$title = preg_replace("/[^\^]*<\!\-\-\:".$lang."\-\->([^<]+)<\!\-\-\:\-\->[^\^]*/","$1",$title);
	
	if (!empty($title) && strpos($args[0],$title)==0 && strlen($args[0])==strlen($title) && $customtitle = get_post_meta($post->ID, '_title_'.$lang, true)) {
		return str_replace($title,$customtitle,$args[0]);
	} else {
		return $args[0];
	}
}

// Changing the wp_title() Template Tag
function ct_wp_title() {
	global $post,$language,$q_config;
	
	$args = func_get_args();
	$args[0] = str_replace('&amp;','&#038;',$args[0]);
	$title = ct_enc($post->post_title);
	
	if (!isset($language)) $lang = (isset($q_config)) ? $q_config['language'] : $GLOBALS['WP_Multilingual_Langs']['default']['lang_shortcode'];
	else $lang = $language;
	
	$title = preg_replace("/[^\^]*<\!\-\-\:".$lang."\-\->([^<]+)<\!\-\-\:\-\->[^\^]*/","$1",$title);
	
	if ($customtitle = get_post_meta($post->ID, '_title_'.$lang, true)) return str_replace($title,$customtitle,$args[0]);
	else return $args[0];
}

// By default, WP uses the_title filter into wp_list_pages, we need to override it somehow
function ct_list_pages() {
	global $post,$language,$q_config,$wpdb;
	$args = func_get_args();
	
	$args[0] = str_replace('&amp;','&#038;',$args[0]);
	
	if (!isset($language)) $lang = (isset($q_config)) ? $q_config['language'] : $GLOBALS['WP_Multilingual_Langs']['default']['lang_shortcode'];
	else $lang = $language;
	
	$title = $post->post_title;
	$title = preg_replace("/[^\^]*<\!\-\-\:".$lang."\-\->([^<]+)<\!\-\-\:\-\->[^\^]*/","$1",$title);
	$title = ct_enc($title);
	
	// set the custom heading for title attribute in the <a> tags
	$headings = $wpdb->get_results("SELECT post_id,meta_value FROM {$wpdb->postmeta} WHERE meta_key = '_title_{$lang}'");
	if (!empty($headings)) {
		
		$titles = $wpdb->get_results("SELECT ID,post_title FROM {$wpdb->posts} WHERE post_type = 'page'");
		$org_titles = array();
		
		foreach ($titles as $v) $org_titles[$v->ID] = $v->post_title;
		
		foreach ($headings as $heading) {
			$org_title = apply_filters('the_title',$org_titles[$heading->post_id]);
			$args[0] = str_replace('title="'.$org_title.'"','title="'.htmlentities($heading->meta_value,ENT_QUOTES,get_bloginfo('charset')).'"',$args[0]);
		}
		
	}
	
	if ($customtitle = get_post_meta($post->ID, '_title_'.$lang, true)) return str_replace('>'.$customtitle.'<','>'.$title.'<',$args[0]);
	else return $args[0];
}

// Attaching our new functions to the Hooks
//add_action('edit_form_advanced', 'ct_addTitleField');
add_action('edit_page_form', 'ct_addTitleField');
//add_action('simple_edit_form', 'ct_addTitleField');

add_action('admin_head','ct_addHead',999);

add_action('save_post', 'ct_updateTitle');

add_filter('the_title', 'ct_the_title',999);
add_filter('wp_title', 'ct_wp_title',999);
add_filter('wp_list_pages','ct_list_pages',999);

?>